@@ -10,7 +10,6 @@ from typing import Any, Iterator, List, Type, Union
 
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
-from flaky import flaky
 from packaging.version import Version
 from pytest_mock import MockerFixture
 
@@ -67,6 +66,17 @@ def test_runtime_mismatch_ansible_module(monkeypatch: MonkeyPatch) -> None:
 def test_runtime_require_module() -> None:
     """Check that require_module successful pass."""
     Runtime(require_module=True)
+    # Now we try to set the collection path, something to check if that is
+    # causing an exception, as 2.15 introduced new init code.
+    from ansible.utils.collection_loader import (  # pylint: disable=import-outside-toplevel
+        AnsibleCollectionConfig,
+    )
+
+    AnsibleCollectionConfig.playbook_paths = "."
+    # Calling it again in order to see that it does not produce UserWarning: AnsibleCollectionFinder has already been configured
+    # which is done by Ansible core 2.15+. We added special code inside Runtime
+    # that should avoid initializing twice and raise that warning.
+    Runtime(require_module=True)
 
 
 def test_runtime_version_fail_module(mocker: MockerFixture) -> None:
@@ -213,8 +223,6 @@ def remember_cwd(cwd: str) -> Iterator[None]:
         os.chdir(curdir)
 
 
-# # https://github.com/box/flaky/issues/170
-@flaky(max_runs=3)  # type: ignore
 def test_prerun_reqs_v1(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> None:
     """Checks that the linter can auto-install requirements v1 when found."""
     cwd = os.path.realpath(
@@ -234,7 +242,6 @@ def test_prerun_reqs_v1(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> N
     )
 
 
-@flaky(max_runs=3)  # type: ignore
 def test_prerun_reqs_v2(caplog: pytest.LogCaptureFixture, runtime: Runtime) -> None:
     """Checks that the linter can auto-install requirements v2 when found."""
     cwd = os.path.realpath(
@@ -375,13 +382,13 @@ def test_require_collection_wrong_version(runtime: Runtime) -> None:
             "ansible-galaxy",
             "collection",
             "install",
-            "containers.podman",
+            "examples/reqs_v2/community-molecule-0.1.0.tar.gz",
             "-p",
             "~/.ansible/collections",
         ]
     )
     with pytest.raises(InvalidPrerequisiteError) as pytest_wrapped_e:
-        runtime.require_collection("containers.podman", "9999.9.9")
+        runtime.require_collection("community.molecule", "9999.9.9")
     assert pytest_wrapped_e.type == InvalidPrerequisiteError
     assert pytest_wrapped_e.value.code == INVALID_PREREQUISITES_RC
 
@@ -439,14 +446,16 @@ def test_require_collection_missing(
 
 def test_install_collection(runtime: Runtime) -> None:
     """Check that valid collection installs do not fail."""
-    runtime.install_collection("containers.podman:>=1.0")
+    runtime.install_collection("examples/reqs_v2/community-molecule-0.1.0.tar.gz")
 
 
 def test_install_collection_dest(runtime: Runtime, tmp_path: pathlib.Path) -> None:
     """Check that valid collection to custom destination passes."""
-    runtime.install_collection("containers.podman:>=1.0", destination=tmp_path)
+    runtime.install_collection(
+        "examples/reqs_v2/community-molecule-0.1.0.tar.gz", destination=tmp_path
+    )
     expected_file = (
-        tmp_path / "ansible_collections" / "containers" / "podman" / "MANIFEST.json"
+        tmp_path / "ansible_collections" / "community" / "molecule" / "MANIFEST.json"
     )
     assert expected_file.is_file()
 
@@ -454,7 +463,7 @@ def test_install_collection_dest(runtime: Runtime, tmp_path: pathlib.Path) -> No
 def test_install_collection_fail(runtime: Runtime) -> None:
     """Check that invalid collection install fails."""
     with pytest.raises(AnsibleCompatError) as pytest_wrapped_e:
-        runtime.install_collection("containers.podman:>=9999.0")
+        runtime.install_collection("community.molecule:>=9999.0")
     assert pytest_wrapped_e.type == InvalidPrerequisiteError
     assert pytest_wrapped_e.value.code == INVALID_PREREQUISITES_RC
 
@@ -466,7 +475,7 @@ def test_install_galaxy_role(runtime_tmp: Runtime) -> None:
     pathlib.Path(f"{runtime_tmp.project_dir}/meta/main.yml").touch()
     # this should only raise a warning
     runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=1)
-    # this shoul test the bypass role name check path
+    # this should test the bypass role name check path
     runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=2)
     # this should raise an error
     with pytest.raises(
@@ -564,15 +573,15 @@ def test_upgrade_collection(runtime_tmp: Runtime) -> None:
     runtime_tmp.prepare_environment()
 
     # we install specific oudated version of a collection
-    runtime_tmp.install_collection("containers.podman:==1.6.0")
+    runtime_tmp.install_collection("examples/reqs_v2/community-molecule-0.1.0.tar.gz")
     with pytest.raises(
         InvalidPrerequisiteError,
-        match="Found containers.podman collection 1.6.0 but 1.6.1 or newer is required.",
+        match="Found community.molecule collection 0.1.0 but 9.9.9 or newer is required.",
     ):
         # we check that when install=False, we raise error
-        runtime_tmp.require_collection("containers.podman", "1.6.1", install=False)
-    # now we really perform the upgrade
-    runtime_tmp.require_collection("containers.podman", "1.6.1")
+        runtime_tmp.require_collection("community.molecule", "9.9.9", install=False)
+    # this should not fail, as we have this version
+    runtime_tmp.require_collection("community.molecule", "0.1.0")
 
 
 def test_require_collection_no_cache_dir() -> None:
@@ -643,16 +652,19 @@ def test_install_collection_from_disk_fail() -> None:
     """Tests that we fail to install a broken collection."""
     with remember_cwd("test/collections/acme.broken"):
         runtime = Runtime(isolated=True)
-        exception: Type[Exception]
-        if runtime.version_in_range(upper="2.11"):
-            exception = AnsibleCommandError
-            msg = "Got 1 exit code while running: ansible-galaxy collection build"
-        else:
-            exception = InvalidPrerequisiteError
-            msg = "is missing the following mandatory"
-        with pytest.raises(exception, match=msg):
-            # this should call install_collection_from_disk(".")
+        with pytest.raises(RuntimeError) as exc_info:
             runtime.prepare_environment(install_local=True)
+        # based on version of Ansible used, we might get a different error,
+        # but both errors should be considered acceptable
+        assert exc_info.type in (
+            RuntimeError,
+            AnsibleCompatError,
+            AnsibleCommandError,
+            InvalidPrerequisiteError,
+        )
+        assert exc_info.match(
+            "(is missing the following mandatory|Got 1 exit code while running: ansible-galaxy collection build)"
+        )
 
 
 def test_prepare_environment_offline_role() -> None:
